[![check](https://github.com/retospect/phagetrix/actions/workflows/check.yml/badge.svg)](https://github.com/retospect/phageterix/actions/workflows/check.yml)
[![Open in Google Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/retospect/phagetrix/blob/main/phagetrix.ipynb)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7676572.svg)](https://doi.org/10.5281/zenodo.7676572)



# Phagetrix

A codon optimizer for phage display library generation.

## Try before buy

Try in Google Colab for free right now: 
[![Open in Google Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/retospect/phagetrix/blob/main/phagetrix.ipynb)
